# cybersf

[![PyPI](https://img.shields.io/pypi/v/cybersf?color=orange&logo=pypi&logoColor=orange&style=flat-square)](https://pypi.org/project/cybersf/)
[![Python Version](https://img.shields.io/badge/python-3.7%2B-blue?logo=python&style=flat-square)](https://www.python.org/downloads/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/cybersf?style=flat-square)
[![Docker Image Size (tag)](https://img.shields.io/docker/image-size/khulnasoft/cybersf/latest?style=flat-square)](https://hub.docker.com/r/khulnasoft/cybersf)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-organge.svg?logo=git&logoColor=organge&style=flat-square)](http://makeapullrequest.com)
[![Open in Visual Studio Code](https://img.shields.io/badge/VSCode-Open-0098FF?style=flat-square)](https://open.vscode.dev/khulnasoft/cybersf)
[![Twitter Follow](https://img.shields.io/twitter/follow/khulnasoft?color=blue&style=flat-square)](https://twitter.com/khulnasoft)

A Modular Penetration Testing Framework

[![Packages](https://img.shields.io/badge/PACKAGES.md-red?style=flat-square)](https://github.com/khulnasoft/cybersf/blob/main/PACKAGES.md)
[![Changelog](https://img.shields.io/badge/CHANGELOG.md-red?style=flat-square)](https://github.com/khulnasoft/cybersf/blob/main/CHANGELOG.md)

## Install

```bash
pip install cybersf
```

## Update

```bash
pip install --upgrade cybersf
```

## Usage

```bash
usage: cybersf [-h] [-i] [-s]

A Penetration Testing Framework

optional arguments:
  -h, --help     show this help message and exit
  -i, --info     gets cybersf info
  -s, --suggest  suggest a tool
```

## Docker

```bash
docker pull khulnasoft/cybersf
docker run -it khulnasoft/cybersf cybersf
```

## Developing

```bash
git clone https://github.com/khulnasoft/cybersf.git
pip install -e ".[dev]"
```

## License

This software is licensed under the [MIT](https://github.com/khulnasoft/cybersf/blob/main/LICENSE) License.

![Fuck It Ship It](https://img.shields.io/badge/fuck%20it-ship%20it-blue?style=flat-square)
